@@ -10,12 +10,12 @@ use warnings;
 use base qw( Tickit::Widget );
 use Tickit::Style;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Carp;
 
 use Tickit::Utils qw( textwidth );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 
 use constant CAN_FOCUS => 1;
 
